=== modified file 'NEWS'
--- NEWS	2005-10-18 06:42:17 +0000
+++ NEWS	2005-10-18 06:56:24 +0000
@@ -26,6 +26,9 @@
       gpg_signing_command (defaults to gpg) and record a digital signature
       of your commit. (Robert Collins)
 
+    * 'bzr pull' now accepts '--clobber' which will discard local changes
+      and make this branch identical to the source branch. (Robert Collins)
+
   TESTING:
 
     * The 'bzr selftest --pattern' option for has been removed, now 
@@ -82,6 +85,8 @@
       from its branch'. (Robert Collins)
 
     * 'pull' has been factored out of the command as WorkingTree.pull().
+      A new option to WorkingTree.pull has been added, clobber, which will
+      ignore diverged history and pull anyway.
       (Robert Collins)
 
 bzr 0.1.1 2005-10-12

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2005-10-18 05:26:22 +0000
+++ bzrlib/branch.py	2005-10-18 06:56:24 +0000
@@ -676,6 +676,10 @@
             mutter("add {%s} to revision-history" % revision_id)
         rev_history = self.revision_history()
         rev_history.extend(revision_ids)
+        self.set_revision_history(rev_history)
+
+    @needs_write_lock
+    def set_revision_history(self, rev_history):
         self.put_controlfile('revision-history', '\n'.join(rev_history))
 
     def has_revision(self, revision_id):

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2005-10-18 06:42:17 +0000
+++ bzrlib/builtins.py	2005-10-18 06:56:24 +0000
@@ -331,10 +331,10 @@
     If branches have diverged, you can use 'bzr merge' to pull the text changes
     from one into the other.
     """
-    takes_options = ['remember']
+    takes_options = ['remember', 'clobber']
     takes_args = ['location?']
 
-    def run(self, location=None, remember=False):
+    def run(self, location=None, remember=False, clobber=False):
         from bzrlib.merge import merge
         import tempfile
         from shutil import rmtree
@@ -350,7 +350,7 @@
                 location = stored_loc
         br_from = Branch.open(location)
         try:
-            br_to.working_tree().pull(br_from, remember)
+            br_to.working_tree().pull(br_from, remember, clobber)
         except DivergedBranches:
             raise BzrCommandError("These branches have diverged."
                                   "  Try merge.")

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2005-10-17 04:16:40 +0000
+++ bzrlib/option.py	2005-10-18 06:56:24 +0000
@@ -150,6 +150,7 @@
     Option.OPTIONS[name] = Option(name, **kwargs)
 
 _global_option('all')
+_global_option('clobber')
 _global_option('basis', type=str)
 _global_option('diff-options', type=str)
 _global_option('help',

=== modified file 'bzrlib/selftest/blackbox.py'
--- bzrlib/selftest/blackbox.py	2005-10-17 23:13:00 +0000
+++ bzrlib/selftest/blackbox.py	2005-10-18 06:56:24 +0000
@@ -400,7 +400,15 @@
         self.runbzr('commit -m blah2 --unchanged')
         os.chdir('../b')
         self.runbzr('commit -m blah3 --unchanged')
+        # no clobber
         self.runbzr('pull ../a', retcode=1)
+        os.chdir('..')
+        self.runbzr('branch b clobberme')
+        os.chdir('clobberme')
+        self.runbzr('pull --clobber ../a')
+        clobbered = Branch.open('.')
+        self.assertEqual(clobbered.revision_history(),
+                         a.revision_history())
         os.chdir('../a')
         self.runbzr('merge ../b')
         self.runbzr('commit -m blah4 --unchanged')

=== modified file 'bzrlib/selftest/testworkingtree.py'
--- bzrlib/selftest/testworkingtree.py	2005-10-18 06:42:17 +0000
+++ bzrlib/selftest/testworkingtree.py	2005-10-18 06:56:24 +0000
@@ -93,13 +93,26 @@
         self.assertEqual('w', tree.branch._lock_mode)
         tree.unlock()
         self.assertEqual(None, tree.branch._lock_count)
-        
-    def test_pull(self):
+ 
+    def get_pullable_branches(self):
         self.build_tree(['from/', 'from/file', 'to/'])
         br_a = Branch.initialize('from')
         br_a.add('file')
         br_a.commit('foo', rev_id='A')
         br_b = Branch.initialize('to')
+        return br_a, br_b
+ 
+    def test_pull(self):
+        br_a, br_b = self.get_pullable_branches()
         br_b.working_tree().pull(br_a)
         self.failUnless(br_b.has_revision('A'))
         self.assertEqual(['A'], br_b.revision_history())
+
+    def test_pull_clobbers(self):
+        br_a, br_b = self.get_pullable_branches()
+        br_b.commit('foo', rev_id='B')
+        self.assertEqual(['B'], br_b.revision_history())
+        br_b.working_tree().pull(br_a, clobber=True)
+        self.failUnless(br_b.has_revision('A'))
+        self.failUnless(br_b.has_revision('B'))
+        self.assertEqual(['A'], br_b.revision_history())

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2005-10-18 06:42:17 +0000
+++ bzrlib/workingtree.py	2005-10-18 06:56:24 +0000
@@ -306,7 +306,7 @@
                 yield stem
 
     @needs_write_lock
-    def pull(self, source, remember=False):
+    def pull(self, source, remember=False, clobber=False):
         from bzrlib.merge import merge
         source.lock_read()
         try:
@@ -315,8 +315,9 @@
             try:
                 self.branch.update_revisions(source)
             except DivergedBranches:
-                if True:
+                if not clobber:
                     raise
+                self.branch.set_revision_history(source.revision_history())
             new_revision_history = self.branch.revision_history()
             if new_revision_history != old_revision_history:
                 merge((self.basedir, -1), (self.basedir, old_revno), check_clean=False)

